;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "cm-mode" "20260518.1920"
  "Minor mode for CriticMarkup."
  '((emacs  "25.1")
    (cl-lib "0.5"))
  :url "https://github.com/joostkremers/criticmarkup-emacs"
  :commit "a5816175548a821bf62d374b40d6974e4956c44b"
  :revdesc "a5816175548a"
  :keywords '("text" "markdown")
  :authors '(("Joost Kremers" . "joostkremers@fastmail.fm"))
  :maintainers '(("Joost Kremers" . "joostkremers@fastmail.fm")))
